@@ -10,7 +10,7 @@ plot.FamiliasPedigree <- function (x, y, ...)
     sex                 <- ped$sex
     n                   <- 1
     if(all(is.na(dadid)) & all(is.na(momid))) 
-        stop("Cannot plot a pedigree without any relations")
+        stop("Cannot plot a pedigree without any relations.")
     for (i in 1:npers) {
         if (is.na(dadid[i]) && !is.na(momid[i])) {
             id        <- c(id, paste("added", n))
